@@ -40,24 +40,23 @@ def standard_bar_tunning(url,ticker,num_bar, date_tuple_range):
     * diccionario con hyperparametros para las tres barras estandar
     ## {'tick_para': a, 'vol_para': b, 'dol_para': c}
     '''
-
+    
     #obtener el url para aperturar el Zarr
     url = url+ticker+'.zarr'
-    print("url: ",url)
+
     #apertura remota de zarr
     zarrds = zarr.open_group(url)
-    print("zarrds: ",zarrds.value[0])
+
     #si la tupla de fechas tiene un valor distinto a None (str fecha x 2)
     #abre todas las fechas
     zarr_dates = zarrds.date.get_basic_selection()
 
     #encuentra los idxs de la fecha min y fecha max dada en la tupla
     dateIdxs = np.searchsorted(zarr_dates, date_tuple_range)
-    print("dateIdxs :",dateIdxs)
-    print("date_tuple_range: ",date_tuple_range)    
+
     #guarda número de días del zarr| dif. de indexes
     num_days = dateIdxs[1]-dateIdxs[0]
-    print("num_days: ", num_days)
+
     #guarda número prom diario de ticks, volumen o dollar | init: 0 all
     average_ticks_day, average_volume_day, average_dollar_day = 0, 0, 0
 
@@ -104,16 +103,17 @@ def getTEventsCumSum(gRaw,h):
     """
     
     tEvents,sPos,sNeg=[],0,0
-    #diff = np.diff(g)
+
     diff=np.diff(gRaw) #differential | eq. returns
     for i in range(1,diff.shape[0]):
         sPos,sNeg=max(0,sPos+diff[i]),min(0,sNeg+diff[i])
-        #print(sPos,sNeg)
+
         if sNeg<-h:
             sNeg=0;tEvents.append(i)
         elif sPos>h:
             sPos=0;tEvents.append(i)
-    return tEvents#pd.DatetimeIndex(tEvents)
+    return tEvents
+
 
 #@njit
 def matchLength(msg,i,n):
@@ -121,11 +121,6 @@ def matchLength(msg,i,n):
     # i>=n & len(msg)>=i+n
     subS=''
     #if 'n' is not a fixed window, it will be acumulated
-    #print("info antes de match length")
-    #print(range(n))
-    
-    #print(len(msg))
-    #print(" ")
     for l in range(n):
         msg1=msg[i:i+l+1]
         for j in range(i-n,i):
@@ -191,7 +186,7 @@ def entropyFeature(row,
     Outputs:
         - valor float 'entropy'
     """
-    
+
     init, last = row[4], row[7]
     init_ts = datetime.timestamp(init.to_pydatetime()) * 1e3
     last_ts = datetime.timestamp(last.to_pydatetime()) * 1e3
@@ -483,7 +478,7 @@ class HRP():
 def etfTrick(list_bars_stocks, 
              stock_list, 
              k=10000, 
-             lower_bound_index = 50, 
+             lower_bound_index = 25, 
              allocation_approach = 'inv',
              output_type = dict):
     """
