@@ -108,12 +108,19 @@ class EnigmX:
                 
         Outputs:
             - Elementos guardados en dirección 'base_path'
+            
+        Important:
+            - 'uid' & 'pwd' are defined for SQL-Cloud in 
+               'get_feature_importance'.
+               
+               Change if you run this in local-device.
     """
     
     def __init__(self, 
                  bartype, 
                  method, 
                  base_path,
+                 cloud_framework = True,
                  features_sufix = "feature", 
                  label_name = "barrierLabel",
                  time_label_name = "horizon",
@@ -127,13 +134,17 @@ class EnigmX:
         self.label_name = label_name
         self.time_label_name = time_label_name
         self.time_label_index_name = time_label_index_name 
+        self.cloud_framework = cloud_framework
         
         # diccionario con los parámetros generales del Feature Importance
         KfeatureImportanceParams = {
             "pca_comparisson": True,
             "top_features": 10,
-            "score_constraint": 0.6, "driver": "{ODBC Driver 17 for SQL Server}", "uid":"sqlserver","pwd":"J7JA4L0pwz0K56oa",
-            "server_name":"34.67.233.155", 
+            "score_constraint": 0.6, 
+            "driver": "{ODBC Driver 17 for SQL Server}", #change for local SQL
+            "uid":"sqlserver", #change for local SQL
+            "pwd":"J7JA4L0pwz0K56oa",#change for local SQL
+            "server_name":"34.67.233.155", #change for local SQL
             "database":'BARS_FEATURES',
             "rolling_window": 10, 
             "rolling_type":'gaussian', 
@@ -208,9 +219,13 @@ class EnigmX:
         # instancia feature importance
         instance = featureImportance(
             model = model, 
-            method = self.method, driver = self.driver, uid = self.uid, pwd = self.pwd,
+            method = self.method, 
+            driver = self.driver, 
+            uid = self.uid, 
+            pwd = self.pwd,
             list_stocks = list_stocks,
             pca_comparisson = self.pca_comparisson,
+            cloud_framework = self.cloud_framework, #cloud activation
             top_features = self.top_features,
             score_constraint= self.score_constraint,
             server_name = self.server_name,
