@@ -62,6 +62,7 @@ class featureImportance(object):
                  method, 
                  list_stocks,
                  pca_comparisson,
+                 cloud_framework = True,
                  top_features = 10,
                  score_constraint = 0.6,
                  server_name = "DESKTOP-N8JUB39", driver="{ODBC Driver 17 for SQL Server}",uid="sqlserver",pwd="J7JA4L0pwz0K56oa",
@@ -110,15 +111,17 @@ class featureImportance(object):
         self.col_label_type = col_label_type
         self.pca_min_var_expected = pca_min_var_expected
         
+        self.cloud_framework = cloud_framework #cloud activation
+        
     def __instanceOverture__(self):
         
         # instancia feature importance base
         instance = FeatureImportance(
                 server_name = self.server_name,
                 database_name = self.database, 
-		driver = self.driver,
-		uid = self.uid,
-		pwd = self.pwd,
+		        driver = self.driver,
+		        uid = self.uid,
+		        pwd = self.pwd,
                 list_stocks = self.list_stocks, 
                 bartype = self.bartype,
                 depured = self.depured, 
@@ -274,25 +277,42 @@ class featureImportance(object):
                     df_endo[colDates] = df_endo[colDates].astype(str)
                     backtest[colDates] = backtest[colDates].astype(str)
                     
-                    # almacenamientos
-                    df_exo.to_csv(
-                                  "STACKED_EXO_{}_{}.csv".format(
+                    # si no esta activado para cloud, asigna path local primero
+                    if not self.cloud_framework:
+                        
+                        exo_path = "{}STACKED_EXO_{}_{}.csv".format(
+                                      self.pictures_pathout,self.bartype, self.method
+                                      )                        
+                        endo_path = "{}STACKED_ENDO_{}_{}.csv".format(
+                                      self.pictures_pathout, self.bartype, self.method
+                                      )
+                        backtest_path = "{}STACKED_BACKTEST_{}_{}.csv".format(
+                                      self.pictures_pathout, self.bartype, self.method
+                                      )                        
+                    
+                    # si esta activado para cloud, no asignes path local alguno
+                    else: 
+                        
+                        exo_path = "STACKED_EXO_{}_{}.csv".format(
                                       self.bartype, self.method
-                                      ), index=False, 
+                                      )                        
+                        endo_path = "STACKED_ENDO_{}_{}.csv".format(
+                                      self.bartype, self.method
+                                      )
+                        backtest_path = "STACKED_BACKTEST_{}_{}.csv".format(
+                                      self.bartype, self.method
+                                      )
+                        
+                    # almacenamientos
+                    df_exo.to_csv(exo_path, index=False, 
                                   date_format='%Y-%m-%d %H:%M:%S'
                                   )
                     
-                    df_endo.to_csv(
-                                  "STACKED_ENDO_{}_{}.csv".format(
-                                      self.bartype, self.method
-                                      ), index=False, 
+                    df_endo.to_csv(endo_path, index=False, 
                                   date_format='%Y-%m-%d %H:%M:%S'
                                   )          
                     
-                    backtest.to_csv(
-                                  "STACKED_BACKTEST_{}_{}.csv".format(
-                                      self.bartype, self.method
-                                      ), index=False, 
+                    backtest.to_csv(backtest_path, index=False, 
                                   date_format='%Y-%m-%d %H:%M:%S'
                                   )          
                     
