@@ -49,7 +49,7 @@ class QuantmoonSQLManager(object):
         
     """
     def __init__(self, server, database_name, driver,uid,pwd,
-                 base_database='test', globalRange=False,
+                 base_database='TSQL', globalRange=False,
                  loggin="",
                  access=""):
         
@@ -63,20 +63,43 @@ class QuantmoonSQLManager(object):
         self.pwd = pwd
         
         self.database_name = database_name.upper()
-        print(self.server,self.database_name,self.uid,self.pwd)
 
-        self.loggin = ('Driver='+self.driver[0]+';Server='+ self.server +
-                       ';Database='+self.base_database+';Uid='+self.uid[0]+';Pwd='+self.pwd[0]+';')
-        print(self.loggin)
+        print('Accessing SQL Info --->>>')
+        
+        # check if input is string (running local device) or tuple (running google cloud)
+        if type(self.uid) == str and type(self.pwd) == str and type(self.driver) == str:
+            self.loggin =  ('Driver='+self.driver+
+                            ';Server='+ self.server +
+                            ';Database='+self.base_database+
+                            ';Uid='+self.uid+
+                            ';Pwd='+self.pwd+';')
             
+        else:
+            self.loggin = ('Driver='+self.driver[0]+
+                           ';Server='+ self.server +
+                           ';Database='+self.base_database+
+                           ';Uid='+self.uid[0]+
+                           ';Pwd='+self.pwd[0]+';')
+            
+        # setting global Range sufix element
         if self.globalRange:
             self.global_ = '_GLOBAL'
         else:
             self.global_ = '_NOGLOBAL'
-            
-        self.access = ('Driver='+self.driver[0]+';Server='+ self.server +
-                       ';Database='+self.database_name+';Uid='+self.uid[0]+';Pwd='+self.pwd[0]+';')
-        print(self.access)
+        
+        # check if input is string (running local device) or tuple (running google cloud)
+        if type(self.uid) == str and type(self.pwd) == str and type(self.driver) == str:
+            self.access = ('Driver='+self.driver+
+                           ';Server='+ self.server +
+                           ';Database='+self.database_name+
+                           ';Uid='+self.uid+
+                           ';Pwd='+self.pwd+';')
+        else:
+            self.access = ('Driver='+self.driver[0]+
+                           ';Server='+ self.server +
+                           ';Database='+self.database_name+
+                           ';Uid='+self.uid[0]+
+                           ';Pwd='+self.pwd[0]+';')
         
     def __checkDatabase__(self):
         # revisar si la base de datos ya existe con ese nombre
@@ -494,7 +517,7 @@ class DataRespositoryInitialization(object):
         self.zarrObject = zarr.open(
             self.data_dir+"/"+ self.stock +".zarr"
             )
-        print("zarrObject: ",self.zarrObject.value[0])
+
         self.zarrDates = np.array(
             self.zarrObject.date)
         
@@ -517,18 +540,17 @@ class DataRespositoryInitialization(object):
                                     )
         else:
             self.range_dates = [self.start_date]
-        print("range_dates: ",self.range_dates)     
-        print("zarr dates: ",self.zarrDates)
+
         #Get ticks information of Time, Prices and Vol from Zarr Objects    
         self.infoTimePriceVol = open_zarr_general(
             self.zarrDates, self.range_dates, self.zarrObject
             ) 
-        print("infoTimePriceVol: ",self.infoTimePriceVol)
+
         #Check ticks information for removing/fixed missed values
         self.__stateResults__ = check_zarr_data(
             self.infoTimePriceVol
             )
-        print("stateresults: ",self.__stateResults__)
+
     
     def __makeTupleContent__(self, freq, time):
         """
@@ -650,7 +672,7 @@ class DataRespositoryInitialization(object):
                 time: 'd'
             
         """
-        print("barnovect: ",info_tuple)
+
             
         if bartype=='tick':
             
@@ -844,9 +866,8 @@ class DataRespositoryInitialization(object):
         """
         
         # método en desuso para computar las barras 
-        print("freq y time: ", freq,time)    
+
         info_tuple = self.__makeTupleContent__(freq, time)
-        print("info_tuple databundle.py: ",info_tuple)
         
         daily_time_bars = info_tuple[3]
         
