@@ -140,6 +140,7 @@ class SQLEnigmXinterface(object):
                  pathzarr, list_stocks, 
                  bartype, start_date, 
                  end_date, desired_bars, 
+                 referential_base_database = 'TSQL',
                  global_range=True):
         
         self.database_features = 'BARS_FEATURES'
@@ -153,6 +154,7 @@ class SQLEnigmXinterface(object):
         self.start_date = start_date
         self.end_date = end_date
         self.desired_bars = desired_bars
+        self.referential_base_database = referential_base_database
         self.global_range = global_range
         
     def __barTunningProcess__(self, SQLFRAME, dbconn, cursor, tunning_interval):
@@ -165,7 +167,7 @@ class SQLEnigmXinterface(object):
                 ).strftime('%Y-%m-%d'), 
             self.start_date
             )
-        print("path: "+self.pathzarr)
+
         #obtien obj. ray con los parametros tuneados por tipo de barra (dict)
         ray_object_list = [
             standard_bar_tunning.remote(
@@ -180,7 +182,7 @@ class SQLEnigmXinterface(object):
         
         #obten la lista de información con los diccionarios
         list_datasets =  ray.get(ray_object_list)
-        print(list_datasets) 
+
         #transforma los diccionarios en un pandas con los params de tunning x bar
         tunning_pandas = construct_pandas_tunning(list_datasets, self.list_stocks)
         
@@ -677,7 +679,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear la tabla: si la tabla está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database
                     )            
             
             #redefinición del nombre de la tabla a crear
@@ -709,7 +713,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear la tabla: si la tabla está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database                    
                     )            
                 
             #por cada nombre de acción en la lista de acciones 
@@ -740,7 +746,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear la tabla: si la tabla está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database                    
                     )              
                 
             #por cada nombre de acción en la lista de acciones
@@ -772,7 +780,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear tabla: si está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database                    
                     )      
                 
             #lista de listas con [STOCK, TYPE] para escritura en tabla
@@ -836,7 +846,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear la tabla: si la tabla está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database                    
                     )      
                         
                 
@@ -871,7 +883,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear la tabla: si la tabla está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database                    
                     )      
                                 
             #por cada nombre de acción en la lista de acciones 
@@ -903,7 +917,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear la tabla: si la tabla está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database                    
                     )      
                                 
             #por cada nombre de acción en la lista de acciones 
@@ -934,7 +950,9 @@ class SQLEnigmXinterface(object):
                     #boleano para crear la tabla: si la tabla está creada, debe ser False
                     create_database = creation_database, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential SQL Database name just for initialization
+                    referential_base_database = self.referential_base_database                    
                     )                  
             
             dbconn.commit()
@@ -986,7 +1004,9 @@ class SQLEnigmXinterface(object):
             #boleano para crear la tabla: en la inicialización, siempre será False
             create_database = False, 
             #nombre global para cada tabla | "GLOBAL" x defecto
-            global_range = self.global_range
+            global_range = self.global_range,
+            #referential SQL Database name just for initialization
+            referential_base_database = self.referential_base_database               
             )        
         
         #proceso de tunning de barras
