@@ -25,15 +25,16 @@ class FeatureImportance(object):
     def __init__(self, 
                  server_name, 
                  database_name, 
-		driver,
-		uid,
-		pwd,
+                 driver,
+                 uid,
+                 pwd,
                  list_stocks,
                  bartype = 'VOLUME',
                  depured = True, 
                  rolling = True,
                  global_range = True,
                  features_sufix = 'feature',
+                 referential_base_database = 'TSQL',
                  window = None,
                  win_type = None,
                  add_parameter = None, 
@@ -59,6 +60,8 @@ class FeatureImportance(object):
         self.col_t1_type = col_t1_type
         self.col_label_type = col_label_type
         
+        self.referential_base_database = referential_base_database
+        
     def __getStacked__(self):
         """
         Open individual csv and merge them to generate stacked.
@@ -73,7 +76,9 @@ class FeatureImportance(object):
                     #boleano para crear la tabla
                     create_database = False, 
                     #nombre global para cada tabla | "GLOBAL" x defecto
-                    global_range = self.global_range
+                    global_range = self.global_range,
+                    #referential database for SQL initial Loc
+                    referential_base_database = self.referential_base_database
                     )                    
         
         #lista con tablas/dataframes por acción extraídas de SQL
