@@ -11,7 +11,9 @@ from sklearn.ensemble import GradientBoostingClassifier
 
 instance = EnigmX(bartype = 'VOLUME', 
                   method = 'MDA', 
-                  base_path = '/home/heligp4/.local/lib/python3.7/site-packages/enigmx/') 
+                  base_path = 'C:/data/',
+                  cloud_framework = False
+                  ) 
 
 params_for_tuning = {
     'max_leaf_nodes': list(range(2, 20)), 
@@ -20,8 +22,14 @@ params_for_tuning = {
 
 instance.get_feature_importance(    
                    model = GradientBoostingClassifier(), 
-                   list_stocks = ['ACIW', 'ACN', 'ADBE', 'ADM', 'AEO', 'AES', 'AFL', 'AGCO', 'AGI', 'AGIO'], 
-                   score_constraint = 0.3,server_name="34.67.233.155",database="BARS-FEATURES")
+                   list_stocks = ['ACIW'], 
+                   score_constraint = 0.3,
+                   server_name="WINDOWS-NI805M6",
+                   database="BARS_FEATURES",
+                   uid = '',
+                   pwd='',
+                   driver = "{SQL Server}"
+                   )
 
 instance.get_model_tunning(exo_process = True, endo_process = True, 
                            exo_model = DecisionTreeClassifier(),  
